#include <iostream>
#include <vector>
#include <string>
#include <cmath>

using namespace std;

struct Pour {
    int x, y, thickness, length;
    vector<char> directions;
};

struct Piece {
    // -1 for owned by opponent, 0 for not owned, 1 for owned by you
    int owner;
    int thickness;
};

int W, H, B, P;
vector<vector<int>> importances;
vector<vector<Piece>> cake;

#define MAXTHICKNESS 13
int costs [MAXTHICKNESS + 1] = {0, 1, 3, 9, 27, 81, 243, 729, 2187, 6561, 19683, 59049, 177147, 999999};

void initialize_game() {
    cin >> W >> H >> B >> P;

    importances.resize(W, vector<int>(H));
    cake.resize(W, vector<Piece>(H, {0, 0}));

    for (int y = H - 1; y >= 0; --y) {
        for (int x = 0; x < W; ++x) {
            cin >> importances[x][y];
        }
    }
}

void update_grid(const Pour& pour, int owner) {
    int x = pour.x;
    int y = pour.y;
    for (int i = 0; i < pour.length; ++i) {
        if (cake[x][y].owner == -1 || cake[x][y].thickness < pour.thickness){
            cake[x][y] = {owner, pour.thickness};
        }

        if (i < pour.directions.size()) {
            switch (pour.directions[i]) {
                case 'U': y++; break;
                case 'R': x++; break;
                case 'D': y--; break;
                case 'L': x--; break;
            }
        }
    }
}

void read_opponent_move() {
    Pour pour;
    cin >> pour.x >> pour.y >> pour.thickness >> pour.length;
    pour.directions.resize(max(0, pour.length - 1));
    for (int i = 0; i < max(0, pour.length - 1); i++) {
        cin >> pour.directions[i];
    }

    update_grid(pour, -1);
}

void print_pour(const Pour& pour) {
    cout << pour.x << " " << pour.y << " " << pour.thickness << " " << pour.length << "\n";
    for (char dir : pour.directions) {
        cout << dir << " ";
    }
    cout << endl;
}

void make_move() {
    Pour pour;
    
    if (B == 0) {
        pour = {0, 0, 1, 0, {}};
    } else {
        int thickness = rand() % MAXTHICKNESS + 1;
        while (costs[thickness] > B){
            thickness = rand() % MAXTHICKNESS + 1;
        }
        int length = rand() % (B / costs[thickness]) + 1;
        if (W * H == 1) length = 1;
        int x = rand() % W;
        int y = rand() % H;
        int initx = x, inity = y;
        vector<char> directions;
        while (directions.size() + 1 < length) {
            char pos_directions [4] = {'U', 'D', 'L', 'R'};
            char direction = pos_directions[rand() % 4];
            if (!((direction == 'U' && y == H - 1) ||
                  (direction == 'D' && y == 0) ||
                  (direction == 'R' && x == W - 1) ||
                  (direction == 'L' && x == 0))) {
                directions.push_back(direction);
                switch (direction) {
                    case 'U': y++; break;
                    case 'R': x++; break;
                    case 'D': y--; break;
                    case 'L': x--; break;
                }
            }
        }
        pour = {initx, inity, thickness, length, directions};
    }

    print_pour(pour);
    update_grid(pour, 1);
    B -= costs[pour.thickness] * pour.length;
    P--;
}

int main() {
    initialize_game();
    srand(time(nullptr));

    char start;
    cin >> start;

    if (start == 'Y') {
        make_move();
    }

    while (P > 0) {
        read_opponent_move();
        make_move();
    }

    return 0;
}
