use std::{
    fmt::{Display, Write},
    str::FromStr,
};

use crate::{BotError, Direction, Pen};

impl Display for Direction {
    fn fmt(&self, f: &mut std::fmt::Formatter<'_>) -> std::fmt::Result {
        use Direction::*;
        f.write_char(match self {
            Up => 'U',
            Right => 'R',
            Down => 'D',
            Left => 'L',
        })
    }
}

impl FromStr for Direction {
    type Err = BotError;
    fn from_str(s: &str) -> Result<Self, Self::Err> {
        use Direction::*;
        match s {
            "U" => Ok(Up),
            "R" => Ok(Right),
            "D" => Ok(Down),
            "L" => Ok(Left),
            _ => Err(BotError::PenParseError),
        }
    }
}

impl Display for Pen {
    fn fmt(&self, f: &mut std::fmt::Formatter<'_>) -> std::fmt::Result {
        f.write_fmt(format_args!(
            "{} {} {} {}\n",
            self.x, self.y, self.strength, self.length
        ))?;
        for mov in &self.moves {
            f.write_fmt(format_args!("{} ", mov))?;
        }
        Ok(())
    }
}

impl Pen {
    pub fn is_empty(&self) -> bool {
        self.length == 0
    }
}
