(() => {
  // node_modules/snabbdom/build/htmldomapi.js
  function createElement(tagName2, options) {
    return document.createElement(tagName2, options);
  }
  function createElementNS(namespaceURI, qualifiedName, options) {
    return document.createElementNS(namespaceURI, qualifiedName, options);
  }
  function createDocumentFragment() {
    return parseFragment(document.createDocumentFragment());
  }
  function createTextNode(text) {
    return document.createTextNode(text);
  }
  function createComment(text) {
    return document.createComment(text);
  }
  function insertBefore(parentNode2, newNode, referenceNode) {
    if (isDocumentFragment(parentNode2)) {
      let node = parentNode2;
      while (node && isDocumentFragment(node)) {
        const fragment2 = parseFragment(node);
        node = fragment2.parent;
      }
      parentNode2 = node !== null && node !== void 0 ? node : parentNode2;
    }
    if (isDocumentFragment(newNode)) {
      newNode = parseFragment(newNode, parentNode2);
    }
    if (referenceNode && isDocumentFragment(referenceNode)) {
      referenceNode = parseFragment(referenceNode).firstChildNode;
    }
    parentNode2.insertBefore(newNode, referenceNode);
  }
  function removeChild(node, child) {
    node.removeChild(child);
  }
  function appendChild(node, child) {
    if (isDocumentFragment(child)) {
      child = parseFragment(child, node);
    }
    node.appendChild(child);
  }
  function parentNode(node) {
    if (isDocumentFragment(node)) {
      while (node && isDocumentFragment(node)) {
        const fragment2 = parseFragment(node);
        node = fragment2.parent;
      }
      return node !== null && node !== void 0 ? node : null;
    }
    return node.parentNode;
  }
  function nextSibling(node) {
    var _a;
    if (isDocumentFragment(node)) {
      const fragment2 = parseFragment(node);
      const parent = parentNode(fragment2);
      if (parent && fragment2.lastChildNode) {
        const children = Array.from(parent.childNodes);
        const index = children.indexOf(fragment2.lastChildNode);
        return (_a = children[index + 1]) !== null && _a !== void 0 ? _a : null;
      }
      return null;
    }
    return node.nextSibling;
  }
  function tagName(elm) {
    return elm.tagName;
  }
  function setTextContent(node, text) {
    node.textContent = text;
  }
  function getTextContent(node) {
    return node.textContent;
  }
  function isElement(node) {
    return node.nodeType === 1;
  }
  function isText(node) {
    return node.nodeType === 3;
  }
  function isComment(node) {
    return node.nodeType === 8;
  }
  function isDocumentFragment(node) {
    return node.nodeType === 11;
  }
  function parseFragment(fragmentNode, parentNode2) {
    var _a, _b, _c;
    const fragment2 = fragmentNode;
    (_a = fragment2.parent) !== null && _a !== void 0 ? _a : fragment2.parent = parentNode2 !== null && parentNode2 !== void 0 ? parentNode2 : null;
    (_b = fragment2.firstChildNode) !== null && _b !== void 0 ? _b : fragment2.firstChildNode = fragmentNode.firstChild;
    (_c = fragment2.lastChildNode) !== null && _c !== void 0 ? _c : fragment2.lastChildNode = fragmentNode.lastChild;
    return fragment2;
  }
  var htmlDomApi = {
    createElement,
    createElementNS,
    createTextNode,
    createDocumentFragment,
    createComment,
    insertBefore,
    removeChild,
    appendChild,
    parentNode,
    nextSibling,
    tagName,
    setTextContent,
    getTextContent,
    isElement,
    isText,
    isComment,
    isDocumentFragment
  };

  // node_modules/snabbdom/build/vnode.js
  function vnode(sel, data, children, text, elm) {
    const key = data === void 0 ? void 0 : data.key;
    return { sel, data, children, text, elm, key };
  }

  // node_modules/snabbdom/build/is.js
  var array = Array.isArray;
  function primitive(s) {
    return typeof s === "string" || typeof s === "number" || s instanceof String || s instanceof Number;
  }

  // node_modules/snabbdom/build/init.js
  function isUndef(s) {
    return s === void 0;
  }
  function isDef(s) {
    return s !== void 0;
  }
  var emptyNode = vnode("", {}, [], void 0, void 0);
  function sameVnode(vnode1, vnode22) {
    var _a, _b;
    const isSameKey = vnode1.key === vnode22.key;
    const isSameIs = ((_a = vnode1.data) === null || _a === void 0 ? void 0 : _a.is) === ((_b = vnode22.data) === null || _b === void 0 ? void 0 : _b.is);
    const isSameSel = vnode1.sel === vnode22.sel;
    const isSameTextOrFragment = !vnode1.sel && vnode1.sel === vnode22.sel ? typeof vnode1.text === typeof vnode22.text : true;
    return isSameSel && isSameKey && isSameIs && isSameTextOrFragment;
  }
  function documentFragmentIsNotSupported() {
    throw new Error("The document fragment is not supported on this platform.");
  }
  function isElement2(api, vnode3) {
    return api.isElement(vnode3);
  }
  function isDocumentFragment2(api, vnode3) {
    return api.isDocumentFragment(vnode3);
  }
  function createKeyToOldIdx(children, beginIdx, endIdx) {
    var _a;
    const map = {};
    for (let i = beginIdx; i <= endIdx; ++i) {
      const key = (_a = children[i]) === null || _a === void 0 ? void 0 : _a.key;
      if (key !== void 0) {
        map[key] = i;
      }
    }
    return map;
  }
  var hooks = [
    "create",
    "update",
    "remove",
    "destroy",
    "pre",
    "post"
  ];
  function init(modules, domApi, options) {
    const cbs = {
      create: [],
      update: [],
      remove: [],
      destroy: [],
      pre: [],
      post: []
    };
    const api = domApi !== void 0 ? domApi : htmlDomApi;
    for (const hook of hooks) {
      for (const module of modules) {
        const currentHook = module[hook];
        if (currentHook !== void 0) {
          cbs[hook].push(currentHook);
        }
      }
    }
    function emptyNodeAt(elm) {
      const id = elm.id ? "#" + elm.id : "";
      const classes = elm.getAttribute("class");
      const c = classes ? "." + classes.split(" ").join(".") : "";
      return vnode(api.tagName(elm).toLowerCase() + id + c, {}, [], void 0, elm);
    }
    function emptyDocumentFragmentAt(frag) {
      return vnode(void 0, {}, [], void 0, frag);
    }
    function createRmCb(childElm, listeners) {
      return function rmCb() {
        if (--listeners === 0) {
          const parent = api.parentNode(childElm);
          if (parent !== null) {
            api.removeChild(parent, childElm);
          }
        }
      };
    }
    function createElm(vnode3, insertedVnodeQueue) {
      var _a, _b, _c, _d;
      let i;
      let data = vnode3.data;
      if (data !== void 0) {
        const init2 = (_a = data.hook) === null || _a === void 0 ? void 0 : _a.init;
        if (isDef(init2)) {
          init2(vnode3);
          data = vnode3.data;
        }
      }
      const children = vnode3.children;
      const sel = vnode3.sel;
      if (sel === "!") {
        if (isUndef(vnode3.text)) {
          vnode3.text = "";
        }
        vnode3.elm = api.createComment(vnode3.text);
      } else if (sel === "") {
        vnode3.elm = api.createTextNode(vnode3.text);
      } else if (sel !== void 0) {
        const hashIdx = sel.indexOf("#");
        const dotIdx = sel.indexOf(".", hashIdx);
        const hash = hashIdx > 0 ? hashIdx : sel.length;
        const dot = dotIdx > 0 ? dotIdx : sel.length;
        const tag = hashIdx !== -1 || dotIdx !== -1 ? sel.slice(0, Math.min(hash, dot)) : sel;
        const elm = vnode3.elm = isDef(data) && isDef(i = data.ns) ? api.createElementNS(i, tag, data) : api.createElement(tag, data);
        if (hash < dot)
          elm.setAttribute("id", sel.slice(hash + 1, dot));
        if (dotIdx > 0)
          elm.setAttribute("class", sel.slice(dot + 1).replace(/\./g, " "));
        for (i = 0; i < cbs.create.length; ++i)
          cbs.create[i](emptyNode, vnode3);
        if (primitive(vnode3.text) && (!array(children) || children.length === 0)) {
          api.appendChild(elm, api.createTextNode(vnode3.text));
        }
        if (array(children)) {
          for (i = 0; i < children.length; ++i) {
            const ch = children[i];
            if (ch != null) {
              api.appendChild(elm, createElm(ch, insertedVnodeQueue));
            }
          }
        }
        const hook = vnode3.data.hook;
        if (isDef(hook)) {
          (_b = hook.create) === null || _b === void 0 ? void 0 : _b.call(hook, emptyNode, vnode3);
          if (hook.insert) {
            insertedVnodeQueue.push(vnode3);
          }
        }
      } else if (((_c = options === null || options === void 0 ? void 0 : options.experimental) === null || _c === void 0 ? void 0 : _c.fragments) && vnode3.children) {
        vnode3.elm = ((_d = api.createDocumentFragment) !== null && _d !== void 0 ? _d : documentFragmentIsNotSupported)();
        for (i = 0; i < cbs.create.length; ++i)
          cbs.create[i](emptyNode, vnode3);
        for (i = 0; i < vnode3.children.length; ++i) {
          const ch = vnode3.children[i];
          if (ch != null) {
            api.appendChild(vnode3.elm, createElm(ch, insertedVnodeQueue));
          }
        }
      } else {
        vnode3.elm = api.createTextNode(vnode3.text);
      }
      return vnode3.elm;
    }
    function addVnodes(parentElm, before, vnodes, startIdx, endIdx, insertedVnodeQueue) {
      for (; startIdx <= endIdx; ++startIdx) {
        const ch = vnodes[startIdx];
        if (ch != null) {
          api.insertBefore(parentElm, createElm(ch, insertedVnodeQueue), before);
        }
      }
    }
    function invokeDestroyHook(vnode3) {
      var _a, _b;
      const data = vnode3.data;
      if (data !== void 0) {
        (_b = (_a = data === null || data === void 0 ? void 0 : data.hook) === null || _a === void 0 ? void 0 : _a.destroy) === null || _b === void 0 ? void 0 : _b.call(_a, vnode3);
        for (let i = 0; i < cbs.destroy.length; ++i)
          cbs.destroy[i](vnode3);
        if (vnode3.children !== void 0) {
          for (let j = 0; j < vnode3.children.length; ++j) {
            const child = vnode3.children[j];
            if (child != null && typeof child !== "string") {
              invokeDestroyHook(child);
            }
          }
        }
      }
    }
    function removeVnodes(parentElm, vnodes, startIdx, endIdx) {
      var _a, _b;
      for (; startIdx <= endIdx; ++startIdx) {
        let listeners;
        let rm;
        const ch = vnodes[startIdx];
        if (ch != null) {
          if (isDef(ch.sel)) {
            invokeDestroyHook(ch);
            listeners = cbs.remove.length + 1;
            rm = createRmCb(ch.elm, listeners);
            for (let i = 0; i < cbs.remove.length; ++i)
              cbs.remove[i](ch, rm);
            const removeHook = (_b = (_a = ch === null || ch === void 0 ? void 0 : ch.data) === null || _a === void 0 ? void 0 : _a.hook) === null || _b === void 0 ? void 0 : _b.remove;
            if (isDef(removeHook)) {
              removeHook(ch, rm);
            } else {
              rm();
            }
          } else if (ch.children) {
            invokeDestroyHook(ch);
            removeVnodes(parentElm, ch.children, 0, ch.children.length - 1);
          } else {
            api.removeChild(parentElm, ch.elm);
          }
        }
      }
    }
    function updateChildren(parentElm, oldCh, newCh, insertedVnodeQueue) {
      let oldStartIdx = 0;
      let newStartIdx = 0;
      let oldEndIdx = oldCh.length - 1;
      let oldStartVnode = oldCh[0];
      let oldEndVnode = oldCh[oldEndIdx];
      let newEndIdx = newCh.length - 1;
      let newStartVnode = newCh[0];
      let newEndVnode = newCh[newEndIdx];
      let oldKeyToIdx;
      let idxInOld;
      let elmToMove;
      let before;
      while (oldStartIdx <= oldEndIdx && newStartIdx <= newEndIdx) {
        if (oldStartVnode == null) {
          oldStartVnode = oldCh[++oldStartIdx];
        } else if (oldEndVnode == null) {
          oldEndVnode = oldCh[--oldEndIdx];
        } else if (newStartVnode == null) {
          newStartVnode = newCh[++newStartIdx];
        } else if (newEndVnode == null) {
          newEndVnode = newCh[--newEndIdx];
        } else if (sameVnode(oldStartVnode, newStartVnode)) {
          patchVnode(oldStartVnode, newStartVnode, insertedVnodeQueue);
          oldStartVnode = oldCh[++oldStartIdx];
          newStartVnode = newCh[++newStartIdx];
        } else if (sameVnode(oldEndVnode, newEndVnode)) {
          patchVnode(oldEndVnode, newEndVnode, insertedVnodeQueue);
          oldEndVnode = oldCh[--oldEndIdx];
          newEndVnode = newCh[--newEndIdx];
        } else if (sameVnode(oldStartVnode, newEndVnode)) {
          patchVnode(oldStartVnode, newEndVnode, insertedVnodeQueue);
          api.insertBefore(parentElm, oldStartVnode.elm, api.nextSibling(oldEndVnode.elm));
          oldStartVnode = oldCh[++oldStartIdx];
          newEndVnode = newCh[--newEndIdx];
        } else if (sameVnode(oldEndVnode, newStartVnode)) {
          patchVnode(oldEndVnode, newStartVnode, insertedVnodeQueue);
          api.insertBefore(parentElm, oldEndVnode.elm, oldStartVnode.elm);
          oldEndVnode = oldCh[--oldEndIdx];
          newStartVnode = newCh[++newStartIdx];
        } else {
          if (oldKeyToIdx === void 0) {
            oldKeyToIdx = createKeyToOldIdx(oldCh, oldStartIdx, oldEndIdx);
          }
          idxInOld = oldKeyToIdx[newStartVnode.key];
          if (isUndef(idxInOld)) {
            api.insertBefore(parentElm, createElm(newStartVnode, insertedVnodeQueue), oldStartVnode.elm);
            newStartVnode = newCh[++newStartIdx];
          } else if (isUndef(oldKeyToIdx[newEndVnode.key])) {
            api.insertBefore(parentElm, createElm(newEndVnode, insertedVnodeQueue), api.nextSibling(oldEndVnode.elm));
            newEndVnode = newCh[--newEndIdx];
          } else {
            elmToMove = oldCh[idxInOld];
            if (elmToMove.sel !== newStartVnode.sel) {
              api.insertBefore(parentElm, createElm(newStartVnode, insertedVnodeQueue), oldStartVnode.elm);
            } else {
              patchVnode(elmToMove, newStartVnode, insertedVnodeQueue);
              oldCh[idxInOld] = void 0;
              api.insertBefore(parentElm, elmToMove.elm, oldStartVnode.elm);
            }
            newStartVnode = newCh[++newStartIdx];
          }
        }
      }
      if (newStartIdx <= newEndIdx) {
        before = newCh[newEndIdx + 1] == null ? null : newCh[newEndIdx + 1].elm;
        addVnodes(parentElm, before, newCh, newStartIdx, newEndIdx, insertedVnodeQueue);
      }
      if (oldStartIdx <= oldEndIdx) {
        removeVnodes(parentElm, oldCh, oldStartIdx, oldEndIdx);
      }
    }
    function patchVnode(oldVnode, vnode3, insertedVnodeQueue) {
      var _a, _b, _c, _d, _e, _f, _g, _h;
      const hook = (_a = vnode3.data) === null || _a === void 0 ? void 0 : _a.hook;
      (_b = hook === null || hook === void 0 ? void 0 : hook.prepatch) === null || _b === void 0 ? void 0 : _b.call(hook, oldVnode, vnode3);
      const elm = vnode3.elm = oldVnode.elm;
      if (oldVnode === vnode3)
        return;
      if (vnode3.data !== void 0 || isDef(vnode3.text) && vnode3.text !== oldVnode.text) {
        (_c = vnode3.data) !== null && _c !== void 0 ? _c : vnode3.data = {};
        (_d = oldVnode.data) !== null && _d !== void 0 ? _d : oldVnode.data = {};
        for (let i = 0; i < cbs.update.length; ++i)
          cbs.update[i](oldVnode, vnode3);
        (_g = (_f = (_e = vnode3.data) === null || _e === void 0 ? void 0 : _e.hook) === null || _f === void 0 ? void 0 : _f.update) === null || _g === void 0 ? void 0 : _g.call(_f, oldVnode, vnode3);
      }
      const oldCh = oldVnode.children;
      const ch = vnode3.children;
      if (isUndef(vnode3.text)) {
        if (isDef(oldCh) && isDef(ch)) {
          if (oldCh !== ch)
            updateChildren(elm, oldCh, ch, insertedVnodeQueue);
        } else if (isDef(ch)) {
          if (isDef(oldVnode.text))
            api.setTextContent(elm, "");
          addVnodes(elm, null, ch, 0, ch.length - 1, insertedVnodeQueue);
        } else if (isDef(oldCh)) {
          removeVnodes(elm, oldCh, 0, oldCh.length - 1);
        } else if (isDef(oldVnode.text)) {
          api.setTextContent(elm, "");
        }
      } else if (oldVnode.text !== vnode3.text) {
        if (isDef(oldCh)) {
          removeVnodes(elm, oldCh, 0, oldCh.length - 1);
        }
        api.setTextContent(elm, vnode3.text);
      }
      (_h = hook === null || hook === void 0 ? void 0 : hook.postpatch) === null || _h === void 0 ? void 0 : _h.call(hook, oldVnode, vnode3);
    }
    return function patch2(oldVnode, vnode3) {
      let i, elm, parent;
      const insertedVnodeQueue = [];
      for (i = 0; i < cbs.pre.length; ++i)
        cbs.pre[i]();
      if (isElement2(api, oldVnode)) {
        oldVnode = emptyNodeAt(oldVnode);
      } else if (isDocumentFragment2(api, oldVnode)) {
        oldVnode = emptyDocumentFragmentAt(oldVnode);
      }
      if (sameVnode(oldVnode, vnode3)) {
        patchVnode(oldVnode, vnode3, insertedVnodeQueue);
      } else {
        elm = oldVnode.elm;
        parent = api.parentNode(elm);
        createElm(vnode3, insertedVnodeQueue);
        if (parent !== null) {
          api.insertBefore(parent, vnode3.elm, api.nextSibling(elm));
          removeVnodes(parent, [oldVnode], 0, 0);
        }
      }
      for (i = 0; i < insertedVnodeQueue.length; ++i) {
        insertedVnodeQueue[i].data.hook.insert(insertedVnodeQueue[i]);
      }
      for (i = 0; i < cbs.post.length; ++i)
        cbs.post[i]();
      return vnode3;
    };
  }

  // node_modules/snabbdom/build/h.js
  function addNS(data, children, sel) {
    data.ns = "http://www.w3.org/2000/svg";
    if (sel !== "foreignObject" && children !== void 0) {
      for (let i = 0; i < children.length; ++i) {
        const child = children[i];
        if (typeof child === "string")
          continue;
        const childData = child.data;
        if (childData !== void 0) {
          addNS(childData, child.children, child.sel);
        }
      }
    }
  }
  function h(sel, b, c) {
    let data = {};
    let children;
    let text;
    let i;
    if (c !== void 0) {
      if (b !== null) {
        data = b;
      }
      if (array(c)) {
        children = c;
      } else if (primitive(c)) {
        text = c.toString();
      } else if (c && c.sel) {
        children = [c];
      }
    } else if (b !== void 0 && b !== null) {
      if (array(b)) {
        children = b;
      } else if (primitive(b)) {
        text = b.toString();
      } else if (b && b.sel) {
        children = [b];
      } else {
        data = b;
      }
    }
    if (children !== void 0) {
      for (i = 0; i < children.length; ++i) {
        if (primitive(children[i]))
          children[i] = vnode(void 0, void 0, void 0, children[i], void 0);
      }
    }
    if (sel.startsWith("svg") && (sel.length === 3 || sel[3] === "." || sel[3] === "#")) {
      addNS(data, children, sel);
    }
    return vnode(sel, data, children, text, void 0);
  }

  // node_modules/snabbdom/build/modules/attributes.js
  var xlinkNS = "http://www.w3.org/1999/xlink";
  var xmlnsNS = "http://www.w3.org/2000/xmlns/";
  var xmlNS = "http://www.w3.org/XML/1998/namespace";
  var colonChar = 58;
  var xChar = 120;
  var mChar = 109;
  function updateAttrs(oldVnode, vnode3) {
    let key;
    const elm = vnode3.elm;
    let oldAttrs = oldVnode.data.attrs;
    let attrs = vnode3.data.attrs;
    if (!oldAttrs && !attrs)
      return;
    if (oldAttrs === attrs)
      return;
    oldAttrs = oldAttrs || {};
    attrs = attrs || {};
    for (key in attrs) {
      const cur = attrs[key];
      const old = oldAttrs[key];
      if (old !== cur) {
        if (cur === true) {
          elm.setAttribute(key, "");
        } else if (cur === false) {
          elm.removeAttribute(key);
        } else {
          if (key.charCodeAt(0) !== xChar) {
            elm.setAttribute(key, cur);
          } else if (key.charCodeAt(3) === colonChar) {
            elm.setAttributeNS(xmlNS, key, cur);
          } else if (key.charCodeAt(5) === colonChar) {
            key.charCodeAt(1) === mChar ? elm.setAttributeNS(xmlnsNS, key, cur) : elm.setAttributeNS(xlinkNS, key, cur);
          } else {
            elm.setAttribute(key, cur);
          }
        }
      }
    }
    for (key in oldAttrs) {
      if (!(key in attrs)) {
        elm.removeAttribute(key);
      }
    }
  }
  var attributesModule = {
    create: updateAttrs,
    update: updateAttrs
  };

  // node_modules/snabbdom/build/modules/class.js
  function updateClass(oldVnode, vnode3) {
    let cur;
    let name;
    const elm = vnode3.elm;
    let oldClass = oldVnode.data.class;
    let klass = vnode3.data.class;
    if (!oldClass && !klass)
      return;
    if (oldClass === klass)
      return;
    oldClass = oldClass || {};
    klass = klass || {};
    for (name in oldClass) {
      if (oldClass[name] && !Object.prototype.hasOwnProperty.call(klass, name)) {
        elm.classList.remove(name);
      }
    }
    for (name in klass) {
      cur = klass[name];
      if (cur !== oldClass[name]) {
        elm.classList[cur ? "add" : "remove"](name);
      }
    }
  }
  var classModule = { create: updateClass, update: updateClass };

  // node_modules/snabbdom/build/modules/eventlisteners.js
  function invokeHandler(handler, vnode3, event) {
    if (typeof handler === "function") {
      handler.call(vnode3, event, vnode3);
    } else if (typeof handler === "object") {
      for (let i = 0; i < handler.length; i++) {
        invokeHandler(handler[i], vnode3, event);
      }
    }
  }
  function handleEvent(event, vnode3) {
    const name = event.type;
    const on = vnode3.data.on;
    if (on && on[name]) {
      invokeHandler(on[name], vnode3, event);
    }
  }
  function createListener() {
    return function handler(event) {
      handleEvent(event, handler.vnode);
    };
  }
  function updateEventListeners(oldVnode, vnode3) {
    const oldOn = oldVnode.data.on;
    const oldListener = oldVnode.listener;
    const oldElm = oldVnode.elm;
    const on = vnode3 && vnode3.data.on;
    const elm = vnode3 && vnode3.elm;
    let name;
    if (oldOn === on) {
      return;
    }
    if (oldOn && oldListener) {
      if (!on) {
        for (name in oldOn) {
          oldElm.removeEventListener(name, oldListener, false);
        }
      } else {
        for (name in oldOn) {
          if (!on[name]) {
            oldElm.removeEventListener(name, oldListener, false);
          }
        }
      }
    }
    if (on) {
      const listener = vnode3.listener = oldVnode.listener || createListener();
      listener.vnode = vnode3;
      if (!oldOn) {
        for (name in on) {
          elm.addEventListener(name, listener, false);
        }
      } else {
        for (name in on) {
          if (!oldOn[name]) {
            elm.addEventListener(name, listener, false);
          }
        }
      }
    }
  }
  var eventListenersModule = {
    create: updateEventListeners,
    update: updateEventListeners,
    destroy: updateEventListeners
  };

  // node_modules/snabbdom/build/modules/props.js
  function updateProps(oldVnode, vnode3) {
    let key;
    let cur;
    let old;
    const elm = vnode3.elm;
    let oldProps = oldVnode.data.props;
    let props = vnode3.data.props;
    if (!oldProps && !props)
      return;
    if (oldProps === props)
      return;
    oldProps = oldProps || {};
    props = props || {};
    for (key in props) {
      cur = props[key];
      old = oldProps[key];
      if (old !== cur && (key !== "value" || elm[key] !== cur)) {
        elm[key] = cur;
      }
    }
  }
  var propsModule = { create: updateProps, update: updateProps };

  // node_modules/snabbdom/build/modules/style.js
  var raf = typeof (window === null || window === void 0 ? void 0 : window.requestAnimationFrame) === "function" ? window.requestAnimationFrame.bind(window) : setTimeout;
  var nextFrame = function(fn) {
    raf(function() {
      raf(fn);
    });
  };
  var reflowForced = false;
  function setNextFrame(obj, prop, val) {
    nextFrame(function() {
      obj[prop] = val;
    });
  }
  function updateStyle(oldVnode, vnode3) {
    let cur;
    let name;
    const elm = vnode3.elm;
    let oldStyle = oldVnode.data.style;
    let style = vnode3.data.style;
    if (!oldStyle && !style)
      return;
    if (oldStyle === style)
      return;
    oldStyle = oldStyle || {};
    style = style || {};
    const oldHasDel = "delayed" in oldStyle;
    for (name in oldStyle) {
      if (!(name in style)) {
        if (name[0] === "-" && name[1] === "-") {
          elm.style.removeProperty(name);
        } else {
          elm.style[name] = "";
        }
      }
    }
    for (name in style) {
      cur = style[name];
      if (name === "delayed" && style.delayed) {
        for (const name2 in style.delayed) {
          cur = style.delayed[name2];
          if (!oldHasDel || cur !== oldStyle.delayed[name2]) {
            setNextFrame(elm.style, name2, cur);
          }
        }
      } else if (name !== "remove" && cur !== oldStyle[name]) {
        if (name[0] === "-" && name[1] === "-") {
          elm.style.setProperty(name, cur);
        } else {
          elm.style[name] = cur;
        }
      }
    }
  }
  function applyDestroyStyle(vnode3) {
    let style;
    let name;
    const elm = vnode3.elm;
    const s = vnode3.data.style;
    if (!s || !(style = s.destroy))
      return;
    for (name in style) {
      elm.style[name] = style[name];
    }
  }
  function applyRemoveStyle(vnode3, rm) {
    const s = vnode3.data.style;
    if (!s || !s.remove) {
      rm();
      return;
    }
    if (!reflowForced) {
      vnode3.elm.offsetLeft;
      reflowForced = true;
    }
    let name;
    const elm = vnode3.elm;
    let i = 0;
    const style = s.remove;
    let amount = 0;
    const applied = [];
    for (name in style) {
      applied.push(name);
      elm.style[name] = style[name];
    }
    const compStyle = getComputedStyle(elm);
    const props = compStyle["transition-property"].split(", ");
    for (; i < props.length; ++i) {
      if (applied.indexOf(props[i]) !== -1)
        amount++;
    }
    elm.addEventListener("transitionend", function(ev) {
      if (ev.target === elm)
        --amount;
      if (amount === 0)
        rm();
    });
  }
  function forceReflow() {
    reflowForced = false;
  }
  var styleModule = {
    pre: forceReflow,
    create: updateStyle,
    update: updateStyle,
    destroy: applyDestroyStyle,
    remove: applyRemoveStyle
  };

  // index.js
  var patch = init([
    classModule,
    propsModule,
    styleModule,
    attributesModule,
    eventListenersModule
  ]);
  function eventSVGPoint(event, svg = event.currentTarget.ownerSVGElement || event.currentTarget) {
    const point = svg.createSVGPoint();
    point.x = event.clientX;
    point.y = event.clientY;
    return point.matrixTransform(svg.getScreenCTM().inverse());
  }
  function repeat(n, el) {
    const arr = new Array(n);
    for (let i = 0; i < n; i++)
      arr[i] = window.structuredClone(el);
    return arr;
  }
  var PLAYER_1_HUE = 39;
  var PLAYER_2_HUE = 214;
  var mapViewScale = 0.7;
  var mapViewX = (1 / mapViewScale / 2 - 0.5) * mapViewScale;
  var mapViewY = (1 / mapViewScale / 2 - 0.5) * mapViewScale;
  var dragPt = null;
  var mapTouches = /* @__PURE__ */ new Map();
  var lastTwoFingerParams;
  var width;
  var height;
  var budget;
  var max_pens;
  var valuabilities;
  var valuability_sum;
  var claims;
  var pens;
  var pens_consequences;
  var pen_index;
  var phase;
  var current_game;
  var is_initialized = false;
  var hasFileUrl = false;
  var urlFetchError = null;
  var name_1;
  var name_2;
  var score_1;
  var score_2;
  var budget_1;
  var budget_2;
  var turn;
  function getTwoFingerParams() {
    const [a, b] = mapTouches.values();
    const dx = a.x - b.x;
    const dy = a.y - b.y;
    return {
      x: (a.x + b.x) / 2,
      y: (a.y + b.y) / 2,
      d: Math.sqrt(dx * dx + dy * dy)
    };
  }
  function zoomMap(anchor, factor) {
    const newScale = Math.max(0.01, Math.min(1, mapViewScale * (factor || 0)));
    mapViewX = anchor.x + (mapViewX - anchor.x) * newScale / mapViewScale;
    mapViewY = anchor.y + (mapViewY - anchor.y) * newScale / mapViewScale;
    mapViewScale = newScale;
  }
  function startDrag(event) {
    event.currentTarget.setPointerCapture(event.pointerId);
    dragPt = eventSVGPoint(event);
  }
  function dragDelta(event) {
    const cursor = eventSVGPoint(event);
    const delta = { x: cursor.x - dragPt.x, y: cursor.y - dragPt.y };
    dragPt = cursor;
    return delta;
  }
  function onWheelMap(event) {
    event.preventDefault();
    if (event.ctrlKey) {
      mapViewX -= event.deltaX;
      mapViewY -= event.deltaY;
    } else {
      zoomMap(eventSVGPoint(event), Math.exp(-event.deltaY / 300));
    }
    render();
  }
  function onPointerdownMap(event) {
    event.preventDefault();
    if (document.activeElement != null)
      document.activeElement.blur();
    const cursor = eventSVGPoint(event);
    if (mapTouches.size === 0 && (event.button === 1 || event.button == 0)) {
      startDrag(event);
    }
    if (event.pointerType === "touch") {
      if (mapTouches.size === 1) {
        dragPt = null;
      }
      mapTouches.set(event.pointerId, cursor);
      event.currentTarget.setPointerCapture(event.pointerId);
      if (mapTouches.size === 2) {
        lastTwoFingerParams = getTwoFingerParams();
        render();
        return;
      }
    }
  }
  function onPointermoveMap(event) {
    if (mapTouches.has(event.pointerId)) {
      mapTouches.set(event.pointerId, eventSVGPoint(event));
      if (mapTouches.size === 2) {
        const params = getTwoFingerParams();
        mapViewX += params.x - lastTwoFingerParams.x;
        mapViewY += params.y - lastTwoFingerParams.y;
        zoomMap(params, params.d / lastTwoFingerParams.d);
        lastTwoFingerParams = params;
        render();
      }
    }
    if (dragPt != null) {
      const delta = dragDelta(event);
      mapViewX += delta.x;
      mapViewY += delta.y;
      render();
    }
  }
  function onPointerupMap(event) {
    if (mapTouches.has(event.pointerId)) {
      mapTouches.delete(event.pointerId);
      event.currentTarget.releasePointerCapture(event.pointerId);
    }
    dragPt = null;
  }
  function inSvg(children) {
    return h(
      "svg.main-svg",
      {
        attrs: { viewBox: "0 0 1 1" },
        on: {
          wheel: onWheelMap,
          pointerdown: onPointerdownMap,
          pointermove: onPointermoveMap,
          pointerup: onPointerupMap,
          pointercancel: onPointerupMap
        }
      },
      [
        h("g", { attrs: { transform: `translate(${mapViewX}, ${mapViewY}) scale(${mapViewScale})` } }, children)
      ]
    );
  }
  async function onFileInput(event) {
    if (event.target.files.length >= 1) {
      const file = event.target.files[0];
      parseLogs(await file.text());
    }
  }
  function logFileLoadMenu() {
    return h("input.file-upload-btn", {
      attrs: { type: "file", accept: "application/json,.json" },
      on: { change: onFileInput }
    });
  }
  function resetGameState() {
    pen_index = 0;
    phase = 0;
    claims = repeat(width, repeat(height, { strength: 0, owner: 0 }));
    score_1 = 0;
    score_2 = 0;
    budget_1 = budget;
    budget_2 = budget;
    turn = pens[current_game][pen_index].origin_turn + 1;
  }
  async function parseLogs(text) {
    let data = JSON.parse(text);
    valuabilities = data.game.map;
    valuability_sum = 0;
    for (let x = 0; x < valuabilities.length; x++) {
      for (let y = 0; y < valuabilities[x].length; y++) {
        valuability_sum += Math.max(0, valuabilities[x][y]);
      }
    }
    width = valuabilities.length;
    height = valuabilities[0].length;
    pens = { "Game A": data.log_a, "Game B": data.log_b };
    pens_consequences = { "Game A": [], "Game B": [] };
    budget = data.game.budget;
    max_pens = data.game.max_pens;
    current_game = "Game A";
    name_1 = data.name_1;
    name_2 = data.name_2;
    resetGameState();
    is_initialized = true;
    render();
  }
  function onGameChange(event) {
    current_game = event.target.childNodes[0].data;
    resetGameState();
    render();
  }
  function gameMenu() {
    let A_br = 255;
    let B_br = 255;
    if (current_game == "Game A") {
      A_br = 230;
    } else {
      B_br = 230;
    }
    return h("div.game-selection.button-group", {}, [
      h("button.group-select-button", { on: { click: onGameChange }, style: { backgroundColor: `rgb(${A_br} ${A_br} ${A_br})` } }, "Game A"),
      h("button.group-select-button", { on: { click: onGameChange }, style: { backgroundColor: `rgb(${B_br} ${B_br} ${B_br})` } }, "Game B")
    ]);
  }
  function coveredCells(pen) {
    let x = pen.x;
    let y = pen.y;
    let cells = [[x, y]];
    for (let i = 0; i < pen.length - 1; i++) {
      let direction = pen.moves[i];
      if (direction == "Right") {
        x += 1;
      } else if (direction == "Up") {
        y += 1;
      } else if (direction == "Left") {
        x -= 1;
      } else if (direction == "Down") {
        y -= 1;
      } else {
        alert("Invalid direction");
      }
      cells.push([x, y]);
    }
    return cells;
  }
  function calcNextConsequences() {
    let consequences = [];
    let pen = pens[current_game][pen_index];
    let owner = pen.owner_id;
    pen = pen.pen;
    let covered_cells = coveredCells(pen);
    for (let i = 0; i < covered_cells.length; i++) {
      let [claiming_x, claiming_y] = covered_cells[i];
      if (claims[claiming_x][claiming_y].strength < pen.strength) {
        consequences.push({
          x: claiming_x,
          y: claiming_y,
          original: claims[claiming_x][claiming_y],
          new: { strength: pen.strength, owner }
        });
      }
    }
    pens_consequences[current_game].push(consequences);
  }
  function updateClaim(x, y, new_val) {
    function updateScore(player, change) {
      if (player == 1) {
        score_1 += change;
      }
      if (player == 2) {
        score_2 += change;
      }
    }
    updateScore(claims[x][y].owner, -valuabilities[x][y]);
    updateScore(new_val.owner, valuabilities[x][y]);
    claims[x][y] = new_val;
  }
  function applyConsequences(i, forward) {
    let budget_change = -pens[current_game][i].pen.length * 3 ** (pens[current_game][i].pen.strength - 1);
    if (!forward) {
      budget_change *= -1;
    }
    if (pens[current_game][i].owner_id == 1) {
      budget_1 += budget_change;
    } else {
      budget_2 += budget_change;
    }
    for (let ci = 0; ci < pens_consequences[current_game][i].length; ci++) {
      const consequence = pens_consequences[current_game][i][ci];
      let new_val = consequence.new;
      if (!forward) {
        new_val = consequence.original;
      }
      updateClaim(consequence.x, consequence.y, new_val, forward);
    }
  }
  function playbackForward() {
    if (pen_index == pens[current_game].length) {
      return;
    }
    if (phase == 0) {
      phase = 1;
    } else {
      phase = 0;
      if (pens_consequences[current_game].length == pen_index) {
        calcNextConsequences();
      }
      applyConsequences(pen_index, true);
      pen_index += 1;
    }
    if (pen_index < pens[current_game].length) {
      turn = pens[current_game][pen_index].origin_turn + 1;
    }
    render();
  }
  function playbackBackward() {
    if (phase == 1) {
      phase = 0;
    } else {
      if (pen_index == 0) {
        return;
      }
      phase = 1;
      pen_index -= 1;
      applyConsequences(pen_index, false);
    }
    turn = pens[current_game][pen_index].origin_turn + 1;
    render();
  }
  function playbackRoundForward() {
    playbackForward();
    playbackForward();
  }
  function playbackRoundBackward() {
    playbackBackward();
    playbackBackward();
  }
  function playbackStart() {
    resetGameState();
    render();
  }
  function playbackEnd() {
    while (pen_index < pens[current_game].length) {
      if (pens_consequences[current_game].length == pen_index) {
        calcNextConsequences();
      }
      applyConsequences(pen_index, true);
      pen_index += 1;
    }
    phase = 0;
    turn = max_pens * 2;
    render();
  }
  function ScoresIndicator() {
    let children = [];
    let color_a = `hsl(${PLAYER_1_HUE} 100% 50%)`;
    let color_b = `hsl(${PLAYER_2_HUE} 100% 50%)`;
    let text_offset = 0.1;
    svg_width = window.innerWidth / (window.innerHeight * 0.25) * 1.5;
    function bar(y, part_a, part_b, scores) {
      let bar_children = [];
      if (scores) {
        bar_children.push(h("rect", {
          attrs: {
            x: svg_width * 0.1,
            y,
            width: svg_width * 0.8,
            height: 0.15,
            fill: "lightgray"
          }
        }));
      }
      bar_children.push(h("rect", {
        attrs: {
          x: svg_width * 0.1,
          y,
          width: svg_width * 0.8 * part_a,
          height: 0.15,
          fill: color_a
        }
      }));
      bar_children.push(h("rect", {
        attrs: {
          x: svg_width * (0.9 - 0.8 * part_b),
          y,
          width: svg_width * 0.8 * part_b,
          height: 0.15,
          fill: color_b
        }
      }));
      if (scores) {
        bar_children.push(h("rect", {
          attrs: {
            x: svg_width * 0.499,
            y,
            width: svg_width * 2e-3,
            height: 0.15,
            fill: "black"
          }
        }));
      }
      return h("g", {}, bar_children);
    }
    let y_of = 0.55;
    children.push(h("defs", {}, h(
      "filter",
      { attrs: { x: 0, y: 0, width: 1, height: 1, id: "bg-filter" } },
      [
        h("feFlood", { attrs: { "flood-color": "white", result: "bg", "flood-opacity": 0.6 } }),
        h("feMerge", {}, [
          h("feMergeNode", { attrs: { in: "bg" } }),
          h("feMergeNode", { attrs: { in: "SourceGraphic" } })
        ])
      ]
    )));
    children.push(h("text", { attrs: { x: svg_width * 0.5, y: 0.48, "font-size": 0.2, "text-anchor": "middle", color: "black", filter: "url(#bg-filter)", stroke: "black", "stroke-width": 0.015 } }, `Turn ${turn}/${2 * max_pens}`));
    children.push(h("text", { attrs: { x: svg_width * 0.1, y: 0.72, "font-size": 0.2, fill: color_a } }, `${name_1}`));
    children.push(h("text", { attrs: { x: svg_width * 0.9, y: 0.72, "font-size": 0.2, fill: color_b, "text-anchor": "end" } }, `${name_2}`));
    children.push(h("text", { attrs: { x: svg_width * 0.5, y: 0.72, "font-size": 0.2, "text-anchor": "middle", color: "black", filter: "url(#bg-filter)" } }, "Score"));
    children.push(h("text", { attrs: { x: svg_width * (0.5 - text_offset), y: 0.72, "font-size": 0.2, fill: color_a } }, `${score_1}`));
    children.push(h("text", { attrs: { x: svg_width * (0.5 + text_offset), y: 0.72, "font-size": 0.2, fill: color_b, "text-anchor": "end" } }, `${score_2}`));
    children.push(bar(0.8, Math.max(0, score_1) / valuability_sum, Math.max(0, score_2) / valuability_sum, true));
    children.push(h("text", { attrs: { x: svg_width * 0.5, y: 1.17, "font-size": 0.2, "text-anchor": "middle", color: "black", filter: "url(#bg-filter)" } }, "Budget"));
    children.push(h("text", { attrs: { x: svg_width * (0.5 - text_offset), y: 1.17, "font-size": 0.2, fill: color_a } }, `${budget_1}`));
    children.push(h("text", { attrs: { x: svg_width * (0.5 + text_offset), y: 1.17, "font-size": 0.2, fill: color_b, "text-anchor": "end" } }, `${budget_2}`));
    children.push(bar(1.25, budget_1 / budget / 2, budget_2 / budget / 2, false));
    return h("svg.scores-svg", { attrs: { viewBox: "0 0 1 1.5", preserveAspectRatio: "xMinYMin" } }, children);
  }
  function PlaybackButtons() {
    return h("div.playback-nav", [
      h("button.nav-button", { on: { click: playbackStart }, attrs: { title: "Go to start (Home)" } }, h("svg", h("path", { attrs: { d: "M18 18l-8.5-6L18 6v12zM8 6v12h-2V6h2z" } }))),
      h("button.nav-button", { on: { click: playbackRoundBackward }, attrs: { title: "Previous round (Page Up)" } }, h("svg", h("path", { attrs: { d: "M11 18V6l-8.5 6 8.5 6zm.5-6l8.5 6V6l-8.5 6z" } }))),
      h("button.nav-button", { on: { click: playbackBackward }, attrs: { title: "Previous frame (Left Arrow)" } }, h("svg", h("path", { attrs: { d: "M15.5 18V6l-8.5 6 8.5 6z" } }))),
      h("button.nav-button", { on: { click: playbackForward }, attrs: { title: "Next frame (Right Arrow)" } }, h("svg", h("path", { attrs: { d: "M8.5 18l8.5-6L8.5 6v12z" } }))),
      h("button.nav-button", { on: { click: playbackRoundForward }, attrs: { title: "Next round (Page Down)" } }, h("svg", h("path", { attrs: { d: "M4 18l8.5-6L4 6v12zm9-12v12l8.5-6L13 6z" } }))),
      h("button.nav-button", { on: { click: playbackEnd }, attrs: { title: "Go to end (End)" } }, h("svg", h("path", { attrs: { d: "M6 18l8.5-6L6 6v12zM16 6v12h2V6h-2z" } })))
    ]);
  }
  var MAX_VALUABILITY = 1e3;
  var MAX_STRENGTH = 13;
  function cell(valuability, xi, yi, claim_strength, claim_owner) {
    let s = 1 / Math.max(width, height);
    let children = [
      h("rect", { attrs: { x: xi * s, y: 1 - (yi + 1) * s, width: s, height: s, fill: `#f0f0f0` } })
    ];
    if (claim_strength > 0) {
      let claim_hue = PLAYER_1_HUE;
      if (claim_owner === 2) {
        claim_hue = PLAYER_2_HUE;
      }
      let claim_l = 100 - Math.max(claim_strength + 1, MAX_STRENGTH / 2) / MAX_STRENGTH * 100;
      let claim_opacity = Math.min(1, (claim_strength + 1) / MAX_STRENGTH * 2);
      children.push(
        h("rect", {
          attrs: {
            x: xi * s,
            y: 1 - (yi + 1) * s,
            width: s,
            height: s,
            fill: `hsl(${claim_hue} 100% ${claim_l}%)`,
            "fill-opacity": claim_opacity
          }
        })
      );
      let strength_labels = [];
      let STRENGTH_C = 4.2312;
      let font_s = s / STRENGTH_C;
      if (("" + claim_strength).length == 2) {
        STRENGTH_C = Math.PI;
      }
      let strength_s = s / STRENGTH_C;
      let clip_id = "clip-" + xi + "-" + yi;
      children.push(
        h("defs", {}, [
          h("clipPath", { attrs: { id: clip_id } }, [
            h("rect", { attrs: { x: xi * s, y: 1 - (yi + 1) * s, width: s, height: s } })
          ])
        ])
      );
      for (let x = Math.floor((xi * s - strength_s) / strength_s) * strength_s; x - strength_s < (xi + 1) * s; x += strength_s) {
        for (let y = Math.floor((1 - (yi + 1) * s - strength_s) / strength_s) * strength_s; y - strength_s < 1 - yi * s; y += strength_s) {
          strength_labels.push(
            h("text", {
              attrs: {
                x,
                y,
                fill: `hsl(${claim_hue} 100% ${claim_l}%)`,
                "font-size": font_s,
                "text-anchor": "middle",
                "dominant-baseline": "central",
                stroke: "white",
                "stroke-width": font_s / 9
              }
            }, [`${claim_strength}`])
          );
        }
      }
      children.push(h("g", { attrs: { "clip-path": `url(#${clip_id})` } }, strength_labels));
    }
    children.push(
      h("rect", { attrs: { x: xi * s, y: 1 - (yi + 1) * s, width: s, height: s, fill: `none`, stroke: "black", "stroke-width": s / 20 } })
    );
    if (valuability != 0) {
      let val_s = Math.abs(valuability) / MAX_VALUABILITY * s * 0.6;
      let val_fill = "black";
      if (valuability < 0) {
        val_fill = "red";
      }
      children.push(
        h("rect", {
          attrs: {
            x: (xi + 0.5) * s - val_s / 2,
            y: 1 - (yi + 0.5) * s - val_s / 2,
            width: val_s,
            height: val_s,
            fill: val_fill
          }
        })
      );
    }
    return h("g", {}, children);
  }
  function playingGrid() {
    let cells = [];
    for (let x = 0; x < width; x++) {
      for (let y = 0; y < height; y++) {
        cells.push(cell(valuabilities[x][y], x, y, claims[x][y].strength, claims[x][y].owner));
      }
    }
    return cells;
  }
  function penPreview() {
    if (phase == 1) {
      let pen = pens[current_game][pen_index];
      let children = [];
      let cells = coveredCells(pen.pen);
      let color = `hsl(${PLAYER_1_HUE} 100% 50%)`;
      if (pen.owner_id == 2) {
        color = `hsl(${PLAYER_2_HUE} 100% 50%)`;
      }
      let s = 1 / Math.max(width, height);
      let t = 0.4 * s;
      children.push(h("rect", {
        attrs: {
          x: (cells[0][0] + 0.5) * s - t / 2,
          y: 1 - (cells[0][1] + 0.5) * s - t / 2,
          height: t,
          width: t,
          fill: color
        }
      }));
      for (let i = 0; i < cells.length - 1; i++) {
        let from = cells[i];
        let to = cells[i + 1];
        let x = (from[0] + 0.5) * s - t / 2;
        let y = 1 - (from[1] + 0.5) * s - t / 2;
        let width2 = s + t;
        let height2 = t;
        if (to[1] != from[1]) {
          height2 = width2;
          width2 = t;
        }
        if (to[0] < from[0]) {
          x -= s;
        }
        if (to[1] > from[1]) {
          y -= s;
        }
        children.push(h("rect", {
          attrs: {
            x,
            y,
            height: height2,
            width: width2,
            fill: color
          }
        }));
      }
      return h("g", { attrs: { opacity: 0.5 } }, children);
    } else {
      return h("g");
    }
  }
  function fetchError(error) {
    urlFetchError = error.message;
    render();
  }
  var URL_PREFIX = "#url=";
  if (location.hash.startsWith(URL_PREFIX)) {
    hasFileUrl = true;
    const fileUrl = location.hash.slice(URL_PREFIX.length);
    fetch(fileUrl).then((response) => {
      if (!response.ok) {
        fetchError(new Error(`HTTP ${response.status}`));
      } else {
        response.text().then(
          (text) => parseLogs(text),
          (error) => fetchError(error)
        );
      }
    }, (error) => fetchError(error));
  }
  var vnode2 = document.getElementById("container");
  function render() {
    if (!is_initialized) {
      if (hasFileUrl) {
      } else {
        vnode2 = patch(vnode2, h("div.log-input", {}, [h("p.padme-right", {}, ["Visualization log:"]), logFileLoadMenu()]));
      }
    } else {
      const newVnode = h("div.h-full", [ScoresIndicator(), gameMenu(), inSvg(playingGrid().concat(penPreview())), PlaybackButtons()]);
      vnode2 = patch(vnode2, newVnode);
    }
    let title = "colorclaim visualization";
    if (document.title !== title)
      document.title = title;
  }
  window.addEventListener("resize", render);
  render();
})();
